#
# spec file for package libsysstat-qt5
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name libsysstat
Name:           libsysstat-qt5
Version:        0.4.6
Release:        2.2
Summary:        Library used to query system info and statistics
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/libsysstat/releases/download/%{version}/libsysstat-%{version}.tar.xz
Source1:        https://github.com/lxqt/libsysstat/releases/download/%{version}/libsysstat-%{version}.tar.xz.asc
Source2:        libsysstat-qt5.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  cmake(lxqt-build-tools) >= 0.13.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.15.0

%description
Library used to query system info and statistics.

%package -n libsysstat-qt5-0
Summary:        Library used to query system info and statistics
Group:          System/Libraries
Provides:       libsysstat

%description -n libsysstat-qt5-0
Development libraries for libsysstat.

%package devel
Summary:        Devel files for libsysstat
Group:          Development/Libraries/C and C++
Requires:       libsysstat-qt5-0 = %{version}
Requires:       pkgconfig

%description devel
sysstat libraries for development.

%prep
%setup -q -n %{_name}-%{version}

%build
%cmake -DUSE_QT5=ON
%make_build

%install
%cmake_install

%post -n libsysstat-qt5-0 -p /sbin/ldconfig
%postun -n libsysstat-qt5-0 -p /sbin/ldconfig

%files -n libsysstat-qt5-0
%license COPYING
%doc AUTHORS
%{_libdir}/%{name}.so.0
%{_libdir}/%{name}.so.0.*

%files devel
%{_includedir}/sysstat-qt5
%{_datadir}/cmake/sysstat-qt5
%{_libdir}/pkgconfig/sysstat-qt5.pc
%{_libdir}/%{name}.so

%changelog
* Wed Oct 30 2024 Shawn Dunn <sfalken@opensuse.org>
- Change BuildRequires from lxqt-build-tools-devel to
  cmake(lxqt-build-tools)
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.6:
  * Bumped minimum required Qt version to 5.15 and dropped dead code.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.5:
  * Initialized some variables.
  * Used "= default" to define trivial destructors.
  * Handled Qt5.15's deprecations.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.4.4:
  * Bumped version to 0.4.4
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed libsysstat-qt5.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.4.3
  * C++11 code updates.
  * Removed (duplicated) string casts definitions.
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2:
  * Improved cmake scripting and set cmake_minimum_required to 3.1.0
  * Don't use automatic string conversions
  * Removes local compile definition
* Tue May 22 2018 mvetter@suse.com
- Update to 0.4.1:
  * Bump patch version to 1
  * CMake: Prevent in-source builds
  * Fixed year and https
  * Fixes some lxde mentions
  * Drop Qt foreach.
  * Handle CMake CMP0024
  * Don't export github templates
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.4.0:
  * correct spelling mistake
  * bump version and needed version of lxqt-build-tools
  * liblxqt make no sense here
  * Copied issue template
  * Drops Qt5Core_VERSION_STRING
  * Fixes (#17)
  * Bump years
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.3.3:
  * Bump patch version to 3
  * Simplify include_directories and compile definitions
  * Adds Building project name and Qt version message
  * Adds a minimum Qt minimum version requirement
  * README.md: Add build dependency lxqt-build-tools
  * Use the lxqt-build-tools LXQtCreatePkgConfigFile
  * Use the lxqt-build-tools LXQtCreatePortableHeaders module
  * Use the new lxqt-build-tools package
  * Remove cpack (#14)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.3.2:
  * rare file descriptor leak fixed
  * documentation improvements
* Thu Nov  5 2015 mvetter@suse.com
- Upstream release 0.3.1
* Mon Feb  9 2015 sfalken@opensuse.org
- new upstream version 0.3.0
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.2.0
* Tue May 13 2014 andrea@opensuse.org
- spec file cleanup for factory
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del: libsysstat-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: libsysstat-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  libsysstat-0.1.0.tar.xz
  Del:  _service
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct cmake calls, in favour of %%cmake and %%cmake_install
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _system
  Add: libsysstat.spec
  Add: libsysstat.changes
